@@ -20,10 +20,9 @@ import hl7_v2x_receiver
 ###################################################################
 
 
-# TODO: Improve script structure https://docs.python-guide.org/writing/structure/
 # TODO: Create local git repository and upload project to github https://github.com
-# TODO: Use setuptools and upload software to PyPI https://pypi.org/
 # TODO: Use HL7apy from http://crs4.github.io/hl7apy/index.html instead of python-hl7
+# TODO: Use HL7apy to implement HL7 data types
 # TODO: Use Requests toolbelt to crate the multipartEncoder https://toolbelt.readthedocs.io/en/latest/user.html
 # TODO: Create a white list of allowed HL7 MLLP hostname clients
 # TODO: Implement RPLC document and other types
@@ -48,6 +47,7 @@ class Oru2xds:
 		self.config_logging()
 
 		logger.info("Starting oru2xds %s ...", __version__)
+		logger.info("Log location: %s", config.LOG_DIR_PATH)
 		logger.debug("Logging level for the console is %s", config.LOG_LEVEL_CONSOLE)
 		logger.debug("Logging level for the log file is %s", config.LOG_LEVEL_FILE)
 		logger.info("Affinity Domain Assigning Authority OID: %s", config.AFFINITY_DOMAIN_ASSIGNING_AUTHORITY_OID)
@@ -69,8 +69,13 @@ class Oru2xds:
 	## Logging configuration
 	#
 	def config_logging(self):
+
+		# Setting the log directory to be relative to the package dir
+		path = os.path.abspath(__file__)
+		config.LOG_DIR_PATH = os.path.dirname(path) + "/log"
+
 		# Start logging
-		if not os.path.exists('log') : os.makedirs('log')
+		if not os.path.exists(config.LOG_DIR_PATH) : os.makedirs(config.LOG_DIR_PATH)
 
 		# Levels may be DEBUG, INFO, WARNING, ERROR, CRITICAL
 		logger.setLevel(logging.DEBUG)
@@ -95,7 +100,7 @@ class Oru2xds:
 
 		# File logging
 		dateStr = datetime.now().date().strftime("%Y%m%d")
-		fileHandler = logging.FileHandler('log/oru2xds-{}.log'.format(dateStr))
+		fileHandler = logging.FileHandler(config.LOG_DIR_PATH + '/oru2xds-{}.log'.format(dateStr))
 		if config.LOG_LEVEL_FILE == "DEBUG":
 			fileHandler.setLevel(logging.DEBUG)
 		elif config.LOG_LEVEL_FILE == "INFO":
